@@ -1,9 +1,11 @@
 package tcp
 
 import (
+	"errors"
 	"fmt"
 	"io"
 	"net"
+	"syscall"
 	"time"
 
 	"github.com/pires/go-proxyproto"
@@ -46,14 +48,14 @@ func NewProxy(address string, terminationDelay time.Duration, proxyProtocol *dyn
 
 // ServeTCP forwards the connection to a service.
 func (p *Proxy) ServeTCP(conn WriteCloser) {
-	log.WithoutContext().Debugf("Handling connection from %s to %s", conn.RemoteAddr(), p.address)
+	log.WithoutContext().Debugf("Handling TCP connection from %s to %s", conn.RemoteAddr(), p.address)
 
 	// needed because of e.g. server.trackedConnection
 	defer conn.Close()
 
 	connBackend, err := p.dialBackend()
 	if err != nil {
-		log.WithoutContext().Errorf("Error while connecting to backend: %v", err)
+		log.WithoutContext().Errorf("Error while dialing backend: %v", err)
 		return
 	}
 
@@ -64,7 +66,7 @@ func (p *Proxy) ServeTCP(conn WriteCloser) {
 	if p.proxyProtocol != nil && p.proxyProtocol.Version > 0 && p.proxyProtocol.Version < 3 {
 		header := proxyproto.HeaderProxyFromAddrs(byte(p.proxyProtocol.Version), conn.RemoteAddr(), conn.LocalAddr())
 		if _, err := header.WriteTo(connBackend); err != nil {
-			log.WithoutContext().Errorf("Error while writing proxy protocol headers to backend connection: %v", err)
+			log.WithoutContext().Errorf("Error while writing TCP proxy protocol headers to backend connection: %v", err)
 			return
 		}
 	}
@@ -74,7 +76,14 @@ func (p *Proxy) ServeTCP(conn WriteCloser) {
 
 	err = <-errChan
 	if err != nil {
-		log.WithoutContext().Errorf("Error during connection: %v", err)
+		// Treat connection reset error during a read operation with a lower log level.
+		// This allows to not report an RST packet sent by the peer as an error,
+		// as it is an abrupt but possible end for the TCP session
+		if isReadConnResetError(err) {
+			log.WithoutContext().Debugf("Error while handling TCP connection: %v", err)
+		} else {
+			log.WithoutContext().Errorf("Error while handling TCP connection: %v", err)
+		}
 	}
 
 	<-errChan
@@ -101,16 +110,31 @@ func (p Proxy) connCopy(dst, src WriteCloser, errCh chan error) {
 	_, err := io.Copy(dst, src)
 	errCh <- err
 
+	// Ends the connection with the dst connection peer.
+	// It corresponds to sending a FIN packet to gracefully end the TCP session.
 	errClose := dst.CloseWrite()
 	if errClose != nil {
-		log.WithoutContext().Debugf("Error while terminating connection: %v", errClose)
+		// Calling CloseWrite() on a connection which have a socket which is "not connected" is expected to fail.
+		// It happens notably when the dst connection has ended receiving an RST packet from the peer (within the other connCopy call).
+		// In that case, logging the error is superfluous,
+		// as in the first place we should not have needed to call CloseWrite.
+		if !isSocketNotConnectedError(errClose) {
+			log.WithoutContext().Debugf("Error while terminating TCP connection: %v", errClose)
+		}
+
 		return
 	}
 
 	if p.terminationDelay >= 0 {
 		err := dst.SetReadDeadline(time.Now().Add(p.terminationDelay))
 		if err != nil {
-			log.WithoutContext().Debugf("Error while setting deadline: %v", err)
+			log.WithoutContext().Debugf("Error while setting TCP connection deadline: %v", err)
 		}
 	}
 }
+
+// isSocketNotConnectedError reports whether err is a socket not connected error.
+func isSocketNotConnectedError(err error) bool {
+	var oerr *net.OpError
+	return errors.As(err, &oerr) && errors.Is(err, syscall.ENOTCONN)
+}
